@@ -106,6 +106,7 @@ class TestConfigPackage:
         envconfig = config.envconfigs['python']
         assert envconfig.args_are_paths
         assert not envconfig.recreate
+        assert not envconfig.pip_pre
 
     def test_defaults_distshare(self, tmpdir, newconfig):
         config = newconfig([], "")
@@ -147,6 +148,20 @@ def test_get_homedir(monkeypatch):
     assert get_homedir() == "123"
 
 
+class TestGetcontextname:
+    def test_blank(self, monkeypatch):
+        monkeypatch.setattr(os, "environ", {})
+        assert getcontextname() is None
+
+    def test_jenkins(self, monkeypatch):
+        monkeypatch.setattr(os, "environ", {"JENKINS_URL": "xyz"})
+        assert getcontextname() == "jenkins"
+
+    def test_hudson_legacy(self, monkeypatch):
+        monkeypatch.setattr(os, "environ", {"HUDSON_URL": "xyz"})
+        assert getcontextname() == "jenkins"
+
+
 class TestIniParser:
     def test_getdefault_single(self, tmpdir, newconfig):
         config = newconfig("""
@@ -620,6 +635,24 @@ class TestConfigTestEnv:
             'some_install', '--arg=%s/foo' % config.toxinidir, 'python',
             '{opts}', '{packages}']
 
+    def test_pip_pre(self, newconfig):
+        config = newconfig("""
+            [testenv]
+            pip_pre=true
+        """)
+        envconfig = config.envconfigs['python']
+        assert envconfig.pip_pre
+
+    def test_pip_pre_cmdline_override(self, newconfig):
+        config = newconfig(
+            ['--pre'],
+            """
+            [testenv]
+            pip_pre=false
+        """)
+        envconfig = config.envconfigs['python']
+        assert envconfig.pip_pre
+
     def test_downloadcache(self, newconfig, monkeypatch):
         monkeypatch.delenv("PIP_DOWNLOAD_CACHE", raising=False)
         config = newconfig("""
@@ -927,6 +960,31 @@ class TestConfigTestEnv:
         assert configs["py27"].setenv["X"] == "1"
         assert "X" not in configs["py26"].setenv
 
+    @pytest.mark.issue191
+    def test_factor_use_not_checked(self, newconfig):
+        inisource="""
+            [tox]
+            envlist = py27-{a,b}
+
+            [testenv]
+            deps = b: test
+        """
+        configs = newconfig([], inisource).envconfigs
+        assert set(configs.keys()) == set(['py27-a', 'py27-b'])
+
+    @pytest.mark.issue198
+    def test_factors_groups_touch(self, newconfig):
+        inisource="""
+            [tox]
+            envlist = {a,b}{-x,}
+
+            [testenv]
+            deps=
+                a,b,x,y: dep
+        """
+        configs = newconfig([], inisource).envconfigs
+        assert set(configs.keys()) == set(['a', 'a-x', 'b', 'b-x'])
+
     def test_period_in_factor(self, newconfig):
         inisource="""
             [tox]
