@@ -18,7 +18,7 @@ iswin32 = sys.platform == "win32"
 
 default_factors = {'jython': 'jython', 'pypy': 'pypy', 'pypy3': 'pypy3',
                    'py': sys.executable}
-for version in '24,25,26,27,30,31,32,33,34'.split(','):
+for version in '24,25,26,27,30,31,32,33,34,35'.split(','):
     default_factors['py' + version] = 'python%s.%s' % tuple(version)
 
 def parseconfig(args=None, pkg=None):
@@ -105,6 +105,9 @@ def prepare_parse(pkgname):
         dest="indexurl", metavar="URL",
         help="set indexserver url (if URL is of form name=url set the "
         "url for the 'name' indexserver, specifically)")
+    parser.add_argument("--pre", action="store_true", dest="pre",
+        help="install pre-releases and development versions of dependencies. "
+             "This will pass the --pre option to install_command (pip by default).")
     parser.add_argument("-r", "--recreate", action="store_true",
         dest="recreate",
         help="force recreation of virtual environments")
@@ -284,10 +287,18 @@ class parseini:
 
         config.envlist, all_envs = self._getenvdata(reader, toxsection)
 
-        # configure testenvs
+        # factors used in config or predefined
         known_factors = self._list_section_factors("testenv")
         known_factors.update(default_factors)
         known_factors.add("python")
+
+        # factors stated in config envlist
+        stated_envlist = reader.getdefault(toxsection, "envlist", replace=False)
+        if stated_envlist:
+            for env in _split_env(stated_envlist):
+                known_factors.update(env.split('-'))
+
+        # configure testenvs
         for name in all_envs:
             section = testenvprefix + name
             factors = set(name.split('-'))
@@ -381,15 +392,19 @@ class parseini:
             downloadcache = os.environ.get("PIP_DOWNLOAD_CACHE", downloadcache)
             vc.downloadcache = py.path.local(downloadcache)
 
-        pip_default_opts = ["--pre", "{opts}", "{packages}"]
         vc.install_command = reader.getargv(
             section,
             "install_command",
-            "pip install " + " ".join(pip_default_opts),
+            "pip install {opts} {packages}",
             )
         if '{packages}' not in vc.install_command:
             raise tox.exception.ConfigError(
              "'install_command' must contain '{packages}' substitution")
+        vc.pip_pre = config.option.pre or reader.getbool(
+            section, "pip_pre", False)
+
+        vc.skip_install = reader.getbool(section, "skip_install", False)
+
         return vc
 
     def _getenvdata(self, reader, toxsection):
@@ -451,7 +466,7 @@ def _split_factor_expr(expr):
 
 def _expand_envstr(envstr):
     # split by commas not in groups
-    tokens = re.split(r'(\{[^}]+\})|,', envstr)
+    tokens = re.split(r'((?:\{[^}]+\})+)|,', envstr)
     envlist = [''.join(g).strip()
                for k, g in itertools.groupby(tokens, key=bool) if k]
 
@@ -797,7 +812,7 @@ class CommandParser(object):
         return ps.yield_words
 
 def getcontextname():
-    if 'HUDSON_URL' in os.environ:
+    if any(env in os.environ for env in ['JENKINS_URL', 'HUDSON_URL']):
         return 'jenkins'
     return None
 
